@@ -27,7 +27,7 @@
  
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 78415 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 165255 $")
 
 #include <string.h>
 #include <ctype.h>
@@ -389,6 +389,9 @@ static struct ast_config *realtime_directory(char *context)
 		if (!cat) {
 			ast_log(LOG_WARNING, "Out of memory\n");
 			ast_config_destroy(cfg);
+			if (rtdata) {
+				ast_config_destroy(rtdata);
+			}
 			return NULL;
 		}
 		ast_category_append(cfg, cat);
