@@ -27,7 +27,7 @@
  
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 122314 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 168561 $")
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -92,7 +92,7 @@ static int read_exec(struct ast_channel *chan, void *data)
 	int maxdigits = 255;
 	int tries = 1, to = 0, x = 0;
 	char *argcopy = NULL;
-	struct ind_tone_zone_sound *ts;
+	struct tone_zone_sound *ts;
 	struct ast_flags flags = {0};
 
 	 AST_DECLARE_APP_ARGS(arglist,
