@@ -24,7 +24,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 107461 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 153337 $")
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -662,7 +662,9 @@ static void sms_log (sms_t * h, char status)
 					*p++ = h->ud[n];
 			*p++ = '\n';
 			*p = 0;
-			write (o, line, strlen (line));
+			if (write (o, line, strlen (line)) < 0) {
+				ast_log(LOG_WARNING, "write() failed: %s\n", strerror(errno));
+			}
 			close (o);
 		}
 		*h->oa = *h->da = h->udl = 0;
