@@ -27,7 +27,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 106552 $");
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 177383 $");
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -193,8 +193,11 @@ static int speech_text(struct ast_channel *chan, char *cmd, char *data,
 	if (data == NULL || speech == NULL || !(result = find_result(speech->results, data)))
                 return -1;
 
-	if (result->text != NULL)
+	if (result->text != NULL) {
 		ast_copy_string(buf, result->text, len);
+	} else {
+		buf[0] = '\0';
+	}
 
         return 0;
 }
@@ -219,8 +222,11 @@ static int speech_grammar(struct ast_channel *chan, char *cmd, char *data,
 	if (data == NULL || speech == NULL || !(result = find_result(speech->results, data)))
                 return -1;
 
-	if (result->grammar != NULL)
+	if (result->grammar != NULL) {
 		ast_copy_string(buf, result->grammar, len);
+	} else {
+		buf[0] = '\0';
+	}
 
         return 0;
 }
@@ -322,6 +328,8 @@ static int speech_read(struct ast_channel *chan, char *cmd, char *data,
 		}
 		snprintf(tmp, sizeof(tmp), "%d", results);
 		ast_copy_string(buf, tmp, len);
+	} else {
+		buf[0] = '\0';
 	}
 
 	return 0;
@@ -370,6 +378,8 @@ static int speech_create(struct ast_channel *chan, void *data)
 	datastore->data = speech;
 	ast_channel_datastore_add(chan, datastore);
 
+	pbx_builtin_setvar_helper(chan, "ERROR", NULL);
+
 	ast_module_user_remove(u);
 
 	return 0;
@@ -766,6 +776,7 @@ static int speech_background(struct ast_channel *chan, void *data)
 			speech->results->text = strdup(dtmf);
 			speech->results->grammar = strdup("dtmf");
 		}
+		ast_speech_change_state(speech, AST_SPEECH_STATE_NOT_READY);
 	}
 
         /* See if it was because they hung up */
