@@ -32,7 +32,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 70841 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 110779 $")
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -50,17 +50,17 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision: 70841 $")
 #include "asterisk/pbx.h"
 #include "asterisk/logger.h"
 #include "asterisk/utils.h"
+#include "asterisk/lock.h"
 
 #define CUSTOM_LOG_DIR "/cdr_custom"
 
 #define DATE_FORMAT "%Y-%m-%d %T"
 
 AST_MUTEX_DEFINE_STATIC(lock);
+AST_MUTEX_DEFINE_STATIC(mf_lock);
 
 static char *name = "cdr-custom";
 
-static FILE *mf = NULL;
-
 static char master[PATH_MAX];
 static char format[1024]="";
 
@@ -107,6 +107,8 @@ static int load_config(int reload)
 
 static int custom_log(struct ast_cdr *cdr)
 {
+	FILE *mf = NULL;
+
 	/* Make sure we have a big enough buf */
 	char buf[2048];
 	struct ast_channel dummy;
@@ -124,23 +126,24 @@ static int custom_log(struct ast_cdr *cdr)
 	/* because of the absolutely unconditional need for the
 	   highest reliability possible in writing billing records,
 	   we open write and close the log file each time */
+	ast_mutex_lock(&mf_lock);
 	mf = fopen(master, "a");
-	if (!mf) {
-		ast_log(LOG_ERROR, "Unable to re-open master file %s : %s\n", master, strerror(errno));
-	}
 	if (mf) {
 		fputs(buf, mf);
 		fflush(mf); /* be particularly anal here */
 		fclose(mf);
 		mf = NULL;
+		ast_mutex_unlock(&mf_lock);
+	} else {
+		ast_log(LOG_ERROR, "Unable to re-open master file %s : %s\n", master, strerror(errno));
+		ast_mutex_unlock(&mf_lock);
 	}
+
 	return 0;
 }
 
 static int unload_module(void)
 {
-	if (mf)
-		fclose(mf);
 	ast_cdr_unregister(name);
 	return 0;
 }
@@ -153,8 +156,6 @@ static int load_module(void)
 		res = ast_cdr_register(name, ast_module_info->description, custom_log);
 		if (res)
 			ast_log(LOG_ERROR, "Unable to register custom CDR handling\n");
-		if (mf)
-			fclose(mf);
 		return res;
 	} else 
 		return AST_MODULE_LOAD_DECLINE;
