@@ -23,9 +23,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * Version Info: $Id: chan_h323.h 44684 2006-10-07 14:39:34Z pcadach $
+ * Version Info: $Id: chan_h323.h 177160 2009-02-18 20:06:45Z jpeeler $
  */
 
+#ifndef CHAN_H323_H
+#define CHAN_H323_H
+
 #include <arpa/inet.h>
 
 /*
@@ -194,10 +197,6 @@ extern int h323debug;
 #define H323_DTMF_RFC2833	(1 << 0)
 #define H323_DTMF_INBAND	(1 << 1)
 
-#ifndef BOOL
-#define BOOL int
-#endif
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -252,3 +251,5 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
+
+#endif
