@@ -29,7 +29,7 @@
  
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 111658 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 153337 $")
 
 #include <unistd.h>
 #include <netinet/in.h>
@@ -509,7 +509,9 @@ static int wav_seek(struct ast_filestream *fs, off_t sample_offset, int whence)
 		int i;
 		fseek(fs->f, 0, SEEK_END);
 		for (i=0; i< (offset - max) / MSGSM_FRAME_SIZE; i++) {
-			fwrite(msgsm_silence, 1, MSGSM_FRAME_SIZE, fs->f);
+			if (!fwrite(msgsm_silence, 1, MSGSM_FRAME_SIZE, fs->f)) {
+				ast_log(LOG_WARNING, "fwrite() failed: %s\n", strerror(errno));
+			}
 		}
 	}
 	s->secondhalf = 0;
