@@ -34,7 +34,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 140488 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 172030 $")
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -73,7 +73,8 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision: 140488 $")
 
 struct fast_originate_helper {
 	char tech[AST_MAX_EXTENSION];
-	char data[AST_MAX_EXTENSION];
+	/*! data can contain a channel name, extension number, username, password, etc. */
+	char data[512];
 	int timeout;
 	int format;
 	char app[AST_MAX_APP];
@@ -137,6 +138,7 @@ static struct {
 } command_blacklist[] = {
 	{{ "module", "load", NULL }},
 	{{ "module", "unload", NULL }},
+	{{ "restart", "gracefully", NULL }},
 };
 
 struct mansession {
@@ -1499,8 +1501,15 @@ static int action_getvar(struct mansession *s, const struct message *m)
 
 	if (varname[strlen(varname) - 1] == ')') {
 		char *copy = ast_strdupa(varname);
-
-		ast_func_read(c, copy, workspace, sizeof(workspace));
+		if (!c) {
+			c = ast_channel_alloc(0, 0, "", "", "", "", "", 0, "Bogus/manager");
+			if (c) {
+				ast_func_read(c, copy, workspace, sizeof(workspace));
+				ast_channel_free(c);
+			} else
+				ast_log(LOG_ERROR, "Unable to allocate bogus channel for variable substitution.  Function results may be blank.\n");
+		} else
+			ast_func_read(c, copy, workspace, sizeof(workspace));
 		varval = workspace;
 	} else {
 		pbx_retrieve_variable(c, varname, &varval, workspace, sizeof(workspace), NULL);
@@ -1663,13 +1672,24 @@ static int action_redirect(struct mansession *s, const struct message *m)
 		ast_channel_unlock(chan2);
 		return 0;
 	}
+	if (chan->pbx) {
+		ast_channel_lock(chan);
+		ast_set_flag(chan, AST_FLAG_BRIDGE_HANGUP_DONT); /* don't let the after-bridge code run the h-exten */
+		ast_channel_unlock(chan);
+	}
 	res = ast_async_goto(chan, context, exten, pi);
 	if (!res) {
 		if (!ast_strlen_zero(name2)) {
-			if (chan2)
+			if (chan2) {
+				if (chan2->pbx) {
+					ast_channel_lock(chan2);
+					ast_set_flag(chan2, AST_FLAG_BRIDGE_HANGUP_DONT); /* don't let the after-bridge code run the h-exten */
+					ast_channel_unlock(chan2);
+				}
 				res = ast_async_goto(chan2, context, exten, pi);
-			else
+			} else {
 				res = -1;
+			}
 			if (!res)
 				astman_send_ack(s, m, "Dual Redirect successful");
 			else
@@ -1758,7 +1778,9 @@ static int action_command(struct mansession *s, const struct message *m)
 	final_buf = ast_calloc(1, l + 1);
 	if (buf) {
 		lseek(fd, 0, SEEK_SET);
-		read(fd, buf, l);
+		if (read(fd, buf, l) < 0) {
+			ast_log(LOG_WARNING, "read() failed: %s\n", strerror(errno));
+		}
 		buf[l] = '\0';
 		if (final_buf) {
 			term_strip(final_buf, buf, l);
@@ -2131,11 +2153,15 @@ static int action_userevent(struct mansession *s, const struct message *m)
 {
 	const char *event = astman_get_header(m, "UserEvent");
 	char body[2048] = "";
-	int x, bodylen = 0;
+	int x, bodylen = 0, xlen;
 	for (x = 0; x < m->hdrcount; x++) {
 		if (strncasecmp("UserEvent:", m->headers[x], strlen("UserEvent:"))) {
+			if (sizeof(body) < bodylen + (xlen = strlen(m->headers[x])) + 3) {
+				ast_log(LOG_WARNING, "UserEvent exceeds our buffer length.  Truncating.\n");
+				break;
+			}
 			ast_copy_string(body + bodylen, m->headers[x], sizeof(body) - bodylen - 3);
-			bodylen += strlen(m->headers[x]);
+			bodylen += xlen;
 			ast_copy_string(body + bodylen, "\r\n", 3);
 			bodylen += 2;
 		}
