@@ -25,7 +25,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 128029 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 170158 $")
 
 #include <sys/types.h>
 #include <stdlib.h>
@@ -723,10 +723,16 @@ static char *complete_context_remove_extension_deprecated(const char *line, cons
 						if (++which > state) {
 							/* If there is an extension then return exten@context. */
 							if (ast_get_extension_matchcid(e) && (!strchr(word, '@') || strchr(word, '/'))) {
-								asprintf(&ret, "%s/%s@%s", ast_get_extension_name(e), ast_get_extension_cidmatch(e), ast_get_context_name(c));
+								if (asprintf(&ret, "%s/%s@%s", ast_get_extension_name(e), ast_get_extension_cidmatch(e), ast_get_context_name(c)) < 0) {
+									ast_log(LOG_WARNING, "asprintf() failed: %s\n", strerror(errno));
+									ret = NULL;
+								}
 								break;
 							} else if (!ast_get_extension_matchcid(e) && !strchr(word, '/')) {
-								asprintf(&ret, "%s@%s", ast_get_extension_name(e), ast_get_context_name(c));
+								if (asprintf(&ret, "%s@%s", ast_get_extension_name(e), ast_get_context_name(c)) < 0) {
+									ast_log(LOG_WARNING, "asprintf() failed: %s\n", strerror(errno));
+									ret = NULL;
+								}
 								break;
 							}
 						}
@@ -863,10 +869,16 @@ static char *complete_context_remove_extension(const char *line, const char *wor
 						if (++which > state) {
 							/* If there is an extension then return exten@context. */
 							if (ast_get_extension_matchcid(e) && (!strchr(word, '@') || strchr(word, '/'))) {
-								asprintf(&ret, "%s/%s@%s", ast_get_extension_name(e), ast_get_extension_cidmatch(e), ast_get_context_name(c));
+								if (asprintf(&ret, "%s/%s@%s", ast_get_extension_name(e), ast_get_extension_cidmatch(e), ast_get_context_name(c)) < 0) {
+									ast_log(LOG_WARNING, "asprintf() failed: %s\n", strerror(errno));
+									ret = NULL;
+								}
 								break;
 							} else if (!ast_get_extension_matchcid(e) && !strchr(word, '/')) {
-								asprintf(&ret, "%s@%s", ast_get_extension_name(e), ast_get_context_name(c));
+								if (asprintf(&ret, "%s@%s", ast_get_extension_name(e), ast_get_context_name(c)) < 0) {
+									ast_log(LOG_WARNING, "asprintf() failed: %s\n", strerror(errno));
+									ret = NULL;
+								}
 								break;
 							}
 						}
@@ -2233,7 +2245,11 @@ static int pbx_load_config(const char *config_file)
 	struct ast_config *cfg;
 	char *end;
 	char *label;
+#ifdef LOW_MEMORY
 	char realvalue[256];
+#else
+	char realvalue[8192];
+#endif
 	int lastpri = -2;
 	struct ast_context *con;
 	struct ast_variable *v;
@@ -2478,7 +2494,7 @@ static void pbx_load_users(void)
 					start = x;
 				}
 				for (x = start; x <= finish; x++) {
-					snprintf(tmp, sizeof(tmp), "Zap/%d", x);
+					snprintf(tmp, sizeof(tmp), "%s/%d", dahdi_chan_name, x);
 					append_interface(iface, sizeof(iface), tmp);
 				}
 				chan = strsep(&c, ",");
