@@ -24,7 +24,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 134976 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 160558 $")
 
 #include <sys/stat.h>
 #include <errno.h>
@@ -47,6 +47,7 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision: 134976 $")
 #include "asterisk/module.h"
 #include "asterisk/options.h"
 #include "asterisk/utils.h"
+#include "asterisk/options.h"
 
 /*
  * pbx_spool is similar in spirit to qcall, but with substantially enhanced functionality...
@@ -446,16 +447,22 @@ static void *scan_thread(void *unused)
 	char fn[256];
 	int res;
 	time_t last = 0, next = 0, now;
+	struct timespec ts = { .tv_sec = 1 };
+  
+	while (!ast_fully_booted) {
+		nanosleep(&ts, NULL);
+	}
+
 	for(;;) {
 		/* Wait a sec */
-		sleep(1);
+		nanosleep(&ts, NULL);
 		time(&now);
 		if (!stat(qdir, &st)) {
 			if ((st.st_mtime != last) || (next && (now > next))) {
 #if 0
 				printf("atime: %ld, mtime: %ld, ctime: %ld\n", st.st_atime, st.st_mtime, st.st_ctime);
 				printf("Ooh, something changed / timeout\n");
-#endif				
+#endif
 				next = 0;
 				last = st.st_mtime;
 				dir = opendir(qdir);
@@ -471,8 +478,12 @@ static void *scan_thread(void *unused)
 										if (!next || (res < next)) {
 											next = res;
 										}
-									} else if (res)
+									} else if (res) {
 										ast_log(LOG_WARNING, "Failed to scan service '%s'\n", fn);
+									} else if (!next) {
+										/* Expired entry: must recheck on the next go-around */
+										next = st.st_mtime;
+									}
 								} else {
 									/* Update "next" update if necessary */
 									if (!next || (st.st_mtime < next))
