@@ -1,3 +1,5 @@
+#include "asterisk.h"
+
 #include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -78,10 +80,7 @@ char last_exten[18000];
 char ast_config_AST_CONFIG_DIR[PATH_MAX];
 char ast_config_AST_VAR_DIR[PATH_MAX];
 
-void ast_add_profile(void);
 void ast_cli_register_multiple(void);
-void ast_register_file_version(void);
-void ast_unregister_file_version(void);
 int ast_add_extension2(struct ast_context *con,
 					   int replace, const char *extension, int priority, const char *label, const char *callerid,
 						const char *application, void *data, void (*datad)(void *),
@@ -115,12 +114,6 @@ struct ast_app *pbx_findapp(const char *app)
 	return (struct ast_app*)1; /* so as not to trigger an error */
 }
 
-void ast_add_profile(void)
-{
-	if (!no_comp)
-		printf("Executed ast_add_profile();\n");
-}
-
 int ast_loader_register(int (*updater)(void))
 {
 	return 1;
@@ -145,20 +138,6 @@ void ast_cli_register_multiple(void)
         	printf("Executed ast_cli_register_multiple();\n");
 }
 
-void ast_register_file_version(void)
-{
-	/* if(!no_comp)
-		printf("Executed ast_register_file_version();\n"); */
-	/* I'm erasing this, because I don't think anyone really ever needs to see it anyway */
-}
-
-void ast_unregister_file_version(void)
-{
-	/* if(!no_comp)
-		printf("Executed ast_unregister_file_version();\n"); */
-	/* I'm erasing this, because I don't think anyone really ever needs to see it anyway */
-
-}
 void pbx_substitute_variables_helper(struct ast_channel *c,const char *cp1,char *cp2,int count);
 void pbx_substitute_variables_helper(struct ast_channel *c,const char *cp1,char *cp2,int count)
 {
